@@ -182,7 +182,7 @@ struct Unit  *SnnsCLib::krart_get_winner (TopoPtrArray wta_layer, FlintType winn
                                           activation
                                        */
 
-   FlintType      max_out  = 0.0;      /* contains the maximal activation
+   FlintType      max_out  = 0.0f;      /* contains the maximal activation
                                        */
 
 
@@ -221,7 +221,7 @@ struct Unit  *SnnsCLib::krart_get_winner (TopoPtrArray wta_layer, FlintType winn
    while ((unit_ptr = *topo_ptr++) != NULL) {
 
       if (unit_ptr != winner_ptr) {
-         unit_ptr->Out.output = 0.0;
+         unit_ptr->Out.output = 0.0f;
       } else {
          unit_ptr->Out.output = winner_output;
       } /*if*/
@@ -241,7 +241,7 @@ struct Unit  *SnnsCLib::krart_get_winner (TopoPtrArray wta_layer, FlintType winn
 /*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^*/
 void  SnnsCLib::krart_deleteTouchFlags (void)
 {
-   struct Unit *unit_ptr;
+    struct Unit *unit_ptr;
 
    FOR_ALL_UNITS (unit_ptr) {
 
@@ -261,7 +261,7 @@ void  SnnsCLib::krart_deleteTouchFlags (void)
 /*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^*/
 void  SnnsCLib::krart_init_sorting (void)
 {
-   struct Unit *unit_ptr;
+    struct Unit *unit_ptr;
 
 
    krart_deleteTouchFlags ();
@@ -282,7 +282,7 @@ void  SnnsCLib::krart_init_sorting (void)
 /*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^*/
 int  SnnsCLib::krart_get_NoOfInputUnits (void)
 {
-   struct Unit  *unit_ptr;
+    struct Unit  *unit_ptr;
    int                   count           = 0;
 
 
@@ -306,7 +306,7 @@ int  SnnsCLib::krart_get_NoOfInputUnits (void)
 /*^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^*/
 bool   SnnsCLib::krart_check_undeterminedUnits (void)
 {
-   struct Unit   *unit_ptr;
+    struct Unit   *unit_ptr;
 
    FOR_ALL_UNITS (unit_ptr) {
 
